@@ -1,41 +1,44 @@
 
 nullSim<- function(y, x, gdat, prdat, ped, gmap, hap,
-   method=c("permutation","gene dropping"), vc=NULL, intc=NULL,
-   test = c("None","F","Chisq"), minorGenoFreq=0.05, rmv=TRUE,
-   gr=2, ntimes=10){
+   method = c("permutation","gene dropping"), vc = NULL, intc = NULL,
+   numGeno = FALSE, test = c("None","F","LRT"), minorGenoFreq = 0.05,
+   rmv = TRUE, gr = 2, ntimes = 1000){
    matr<- NULL
    method<- match.arg(method)
    test<- match.arg(test)
    if(method=="gene dropping"){
-      pedR<- pedRecode(ped,all=TRUE,msg=FALSE)
       if(missing(prdat)){
          ids<- rownames(gdat)
-         if(any(!is.element(ids, pedR$old)))
+         if(any(!is.element(ids, ped$id)))
             stop("Not all sample IDs in both 'prdat' and 'ped'?", call.=FALSE)
          pos<- gmap
          for(n in 1:ntimes){
-            gdatTmp<- genoSim(pedR, gmap=gmap, ids=ids, hap=hap, method="Haldane")
+            gdatTmp<- genoSim(ped, gmap=gmap, ids=ids, hap=hap, method="Haldane")
             llkTmp<- scanOne(y=y, x=x, gdat=gdatTmp, vc=vc, intc=intc,
-               test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
+               numGeno=numGeno, test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
 
-            if(minorGenoFreq <= 0 && rmv) matr<- rbind(matr, llkTmp$p) else
-            if(test != "None") stop("Test should be 'None'.", call.=FALSE) else
-            matr<- rbind(matr, max(llkTmp$p))
+            if(test == "None"){
+               matr<- c(matr, max(llkTmp$LRT))
+            }else{
+               matr<- c(matr, max(-log10(llkTmp$pval)))
+            }
          }
       }else{
          ids<- dimnames(prdat$pr)[[1]]
-         if(any(!is.element(ids, pedR$old)))
+         if(any(!is.element(ids, ped$id)))
             stop("Not all sample IDs in both 'prdat' and 'ped'?", call.=FALSE)
          pos<- data.frame(snp=prdat$snp, chr=prdat$chr, dist=prdat$dist)
          for(n in 1:ntimes){
-            gdatTmp<- genoSim(pedR, gmap=gmap, ids=ids, hap=hap, method="Haldane")
+            gdatTmp<- genoSim(ped, gmap=gmap, ids=ids, hap=hap, method="Haldane")
             prd<- genoProb(gdatTmp, gmap, gr=gr, pos=pos, method="Haldane", msg = FALSE)
             llkTmp<- scanOne(y=y, x=x, prdat=prd, vc=vc, intc=intc,
-               test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
+               numGeno=numGeno, test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
 
-            if(minorGenoFreq <= 0 && rmv) matr<- rbind(matr, llkTmp$p) else
-            if(test != "None") stop("Test should be 'None'.", call.=FALSE)
-            else matr<- rbind(matr, max(llkTmp$p))
+            if(test == "None"){
+               matr<- c(matr, max(llkTmp$LRT))
+            }else{
+               matr<- c(matr, max(-log10(llkTmp$pval)))
+            }
          }
       }
    }else if(method=="permutation"){
@@ -44,9 +47,13 @@ nullSim<- function(y, x, gdat, prdat, ped, gmap, hap,
          for(n in 1:ntimes){
             idx<- sample(1:nrow(gdat),replace=FALSE)
             llkTmp<- scanOne(y=y, x=x, gdat=gdat[idx,], vc=vc, intc=intc,
-               test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
+               numGeno=numGeno, test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
 
-            matr<- rbind(matr, llkTmp$p)
+            if(test == "None"){
+               matr<- c(matr, max(llkTmp$LRT))
+            }else{
+               matr<- c(matr, max(-log10(llkTmp$pval)))
+            }
          }
       }else{
          prd<- prdat
@@ -54,9 +61,13 @@ nullSim<- function(y, x, gdat, prdat, ped, gmap, hap,
             idx<- sample(1:dim(prdat$pr)[1], replace=FALSE)
             prd$pr<- prdat$pr[idx,,]
             llkTmp<- scanOne(y=y, x=x, prdat=prd, vc=vc, intc=intc,
-               test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
+               numGeno=numGeno, test=test, minorGenoFreq=minorGenoFreq, rmv=rmv)
 
-            matr<- rbind(matr, llkTmp$p)
+            if(test == "None"){
+               matr<- c(matr, max(llkTmp$LRT))
+            }else{
+               matr<- c(matr, max(-log10(llkTmp$pval)))
+            }
          }
       }
    }else stop("Permutation or gene dropping.", call.=FALSE)
